@@ -4,7 +4,7 @@ from typing import TYPE_CHECKING, Any
 
 if TYPE_CHECKING:
     from langsmith._expect import expect
-    from langsmith._testing import test, unit
+    from langsmith.async_client import AsyncClient
     from langsmith.client import Client
     from langsmith.evaluation import aevaluate, evaluate
     from langsmith.evaluation.evaluator import EvaluationResult, RunEvaluator
@@ -16,20 +16,25 @@ if TYPE_CHECKING:
         tracing_context,
     )
     from langsmith.run_trees import RunTree
+    from langsmith.testing._internal import test, unit
+    from langsmith.utils import ContextThreadPoolExecutor
+
+# Avoid calling into importlib on every call to __version__
+__version__ = "0.3.42"
+version = __version__  # for backwards compatibility
 
 
 def __getattr__(name: str) -> Any:
     if name == "__version__":
-        try:
-            from importlib import metadata
-
-            return metadata.version(__package__)
-        except metadata.PackageNotFoundError:
-            return ""
+        return version
     elif name == "Client":
         from langsmith.client import Client
 
         return Client
+    elif name == "AsyncClient":
+        from langsmith.async_client import AsyncClient
+
+        return AsyncClient
     elif name == "RunTree":
         from langsmith.run_trees import RunTree
 
@@ -52,7 +57,7 @@ def __getattr__(name: str) -> Any:
         return traceable
 
     elif name == "test":
-        from langsmith._testing import test
+        from langsmith.testing._internal import test
 
         return test
 
@@ -64,10 +69,19 @@ def __getattr__(name: str) -> Any:
         from langsmith.evaluation import evaluate
 
         return evaluate
+
+    elif name == "evaluate_existing":
+        from langsmith.evaluation import evaluate_existing
+
+        return evaluate_existing
     elif name == "aevaluate":
         from langsmith.evaluation import aevaluate
 
         return aevaluate
+    elif name == "aevaluate_existing":
+        from langsmith.evaluation import aevaluate_existing
+
+        return aevaluate_existing
     elif name == "tracing_context":
         from langsmith.run_helpers import tracing_context
 
@@ -77,16 +91,19 @@ def __getattr__(name: str) -> Any:
         from langsmith.run_helpers import get_tracing_context
 
         return get_tracing_context
-
     elif name == "get_current_run_tree":
         from langsmith.run_helpers import get_current_run_tree
 
         return get_current_run_tree
 
     elif name == "unit":
-        from langsmith._testing import unit
+        from langsmith.testing._internal import unit
 
         return unit
+    elif name == "ContextThreadPoolExecutor":
+        from langsmith.utils import ContextThreadPoolExecutor
+
+        return ContextThreadPoolExecutor
 
     raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
 
@@ -97,6 +114,7 @@ __all__ = [
     "__version__",
     "EvaluationResult",
     "RunEvaluator",
+    "anonymizer",
     "traceable",
     "trace",
     "unit",
@@ -107,4 +125,6 @@ __all__ = [
     "tracing_context",
     "get_tracing_context",
     "get_current_run_tree",
+    "ContextThreadPoolExecutor",
+    "AsyncClient",
 ]
